| Title: | Conduct Robust Correlations on Non-Normal Data |
|---|---|
| Description: | Allows you to conduct robust correlations on your non-normal data set. The robust correlations included in the package are median-absolute-deviation and median-based correlations. Li, J.C.H. (2022) <doi:10.5964/meth.8467>. |
| Authors: | Johnson Li [aut] (ORCID: <https://orcid.org/0000-0002-2553-117X>), Aurora Robert [cre, aut] (ORCID: <https://orcid.org/0009-0004-9206-1595>) |
| Maintainer: | Aurora Robert <[email protected]> |
| License: | GPL-3 |
| Version: | 0.1.0 |
| Built: | 2026-05-18 07:44:35 UTC |
| Source: | https://github.com/aurora-uofm/correlationr |
Performs a median-absolute-deviation correlation which is used to examine whether two continuous variables (X and Y) are linearly related using a deviate estimation, called the median absolute deviation.
rMAD(x, y)rMAD(x, y)
x |
a continuous variable |
y |
a continuous variable |
a correlation value (r) that ranges from -1 to +1
rMAD(SwimLessons$Temp, SwimLessons$SwimTime)rMAD(SwimLessons$Temp, SwimLessons$SwimTime)
Performs a median based correlation which is used to examine whether two continuous variables (X and Y) are linearly related using a median correlation coefficient.
rMED(x, y)rMED(x, y)
x |
a continuous variable |
y |
a continuous variable |
a correlation value (r) that ranges from -1 to +1
rMED(SwimLessons$Temp, SwimLessons$SwimTime)rMED(SwimLessons$Temp, SwimLessons$SwimTime)
Contains four continuous variables.
SwimLessonsSwimLessons
A data frame with 200 rows and 4 variables:
The age of the person taking swim lessons
The quantity of time the person spent swimming
The temperature of the water during the swim lesson
The UV index during the swim lesson
Created in-house to serve as an example dataset for the package correlationr.
data(SwimLessons)data(SwimLessons)